pub struct PlayerChunkView {
pub center: ChunkPos,
pub view_distance: u8,
}Expand description
A view of chunks around a center chunk.
Fields
center: ChunkPosThe center of the view.
view_distance: u8The view distance in chunks.
Implementations
Sourceimpl PlayerChunkView
impl PlayerChunkView
Sourcepub const fn new(center: ChunkPos, view_distance: u8) -> Self
pub const fn new(center: ChunkPos, view_distance: u8) -> Self
Creates a new ChunkTrackingView with the given center and view distance.
fn min_x(&self) -> i32
fn max_x(&self) -> i32
fn min_z(&self) -> i32
fn max_z(&self) -> i32
Sourcepub fn contains(&self, pos: ChunkPos) -> bool
pub fn contains(&self, pos: ChunkPos) -> bool
Checks if the given chunk position is within the view.
Sourcepub fn is_within_distance(
center_x: i32,
center_z: i32,
view_distance: i32,
chunk_x: i32,
chunk_z: i32,
include_neighbors: bool,
) -> bool
pub fn is_within_distance( center_x: i32, center_z: i32, view_distance: i32, chunk_x: i32, chunk_z: i32, include_neighbors: bool, ) -> bool
Checks if a chunk at (chunk_x, chunk_z) is within the view distance of (center_x, center_z).
fn square_intersects(&self, other: &Self) -> bool
Sourcepub fn difference<T>(
old: &Self,
new: &Self,
on_added: impl FnMut(ChunkPos, &mut T),
on_removed: impl FnMut(ChunkPos, &mut T),
data: &mut T,
)
pub fn difference<T>( old: &Self, new: &Self, on_added: impl FnMut(ChunkPos, &mut T), on_removed: impl FnMut(ChunkPos, &mut T), data: &mut T, )
Calculates the difference between two views, calling on_added for chunks in the new view but not the old,
and on_removed for chunks in the old view but not the new.